==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/eu.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Biltegiratzea ez dago erabilgarri une honetan",
    "Storage invalid" : "Biltegi bliogabea",
    "Unknown error" : "Errore ezezaguna",
    "All files" : "Fitxategi guztiak",
    "Recent" : "Duela gutxi",
    "File could not be found" : "Fitxategia ezin izan da aurkitu",
    "Home" : "Etxekoa",
    "Close" : "Itxi",
    "Favorites" : "Gogokoak",
    "Could not create folder \"{dir}\"" : "Ezin izan da \"{dir}\" karpeta sortu",
    "Upload cancelled." : "Igoera ezeztatuta",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ezin da {filename} igo karpeta bat delako edo 0 byte dituelako",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ez dago leku nahikorik, zu {size1} igotzen ari zara baina bakarrik {size2} libre dago",
    "Target folder \"{dir}\" does not exist any more" : "\"{dir}\" karpeta ez du gehiago existitzen",
    "Not enough free space" : "Ez dago nahiko leku librea",
    "Uploading..." : "Igotzen...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} of {totalSize} ({bitrate})",
    "Actions" : "Ekintzak",
    "Download" : "Deskargatu",
    "Rename" : "Berrizendatu",
    "Move" : "Mugitu",
    "Target folder" : "Xede karpeta",
    "Delete" : "Ezabatu",
    "Disconnect storage" : "Deskonektatu biltegia",
    "Unshare" : "Ez elkarbanatu",
    "Could not load info for file \"{file}\"" : "Ezin izan da \"{file}\" fitxategiaren informazioa kargatu",
    "Files" : "Fitxategiak",
    "Details" : "Xehetasunak",
    "Select" : "hautatu",
    "Pending" : "Zain",
    "Unable to determine date" : "Ezin izan da data zehaztu",
    "This operation is forbidden" : "Eragiketa hau debekatuta dago",
    "This directory is unavailable, please check the logs or contact the administrator" : "Direktorio hau ez dago erabilgarri, begira itzazu erregistroa edo administratzailearekin harremanetan jarri",
    "Could not move \"{file}\", target exists" : "Ezin da \"{file}\" mugitu, helburuan existitzen da jadanik",
    "Could not move \"{file}\"" : "Ezin da mugitu \"{file}\"",
    "{newName} already exists" : "{newName} existitzen da dagoeneko",
    "Could not rename \"{fileName}\", it does not exist any more" : "Ezin izan da \"{fileName}\" berrizendatu, ez da existitzen",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" izena dagoeneko dago erabilita \"{dir}\" karpetan. Mesedez, beste bat aukeratu.",
    "Could not rename \"{fileName}\"" : "Ezin izan da \"{fileName}\" berrizendatu ",
    "Could not create file \"{file}\"" : "Ezin izan da \"{file}\" fitxategia sortu",
    "Could not create file \"{file}\" because it already exists" : "Ezin izan da \"{file}\" fitxategia sortu, dagoeneko existitzen delako",
    "Could not create folder \"{dir}\" because it already exists" : "Ezin izan da \"{dir}\" karpeta sortu, dagoeneko existitzen delako",
    "Error deleting file \"{fileName}\"." : "Akatsa \"{fileName}\" fitxategia ezabatzerakoan.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Ez da '{tag}{filter}{endtag}' bilaketarako emaitzik aurkitu beste karpetetan",
    "Name" : "Izena",
    "Size" : "Tamaina",
    "Modified" : "Aldatuta",
    "_%n folder_::_%n folders_" : ["karpeta %n","%n karpeta"],
    "_%n file_::_%n files_" : ["fitxategi %n","%n fitxategi"],
    "{dirs} and {files}" : "{dirs} eta {files}",
    "_including %n hidden_::_including %n hidden_" : ["including %n hidden","including %n hidden"],
    "You don’t have permission to upload or create files here" : "Ez duzu fitxategiak hona igotzeko edo hemen sortzeko baimenik",
    "_Uploading %n file_::_Uploading %n files_" : ["Fitxategi %n igotzen","%n fitxategi igotzen"],
    "New" : "Berria",
    "\"{name}\" is an invalid file name." : "\"{name}\" ez da fitxategi izen baliogarria.",
    "File name cannot be empty." : "Fitxategi izena ezin da hutsa izan.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" fitxategi mota ez da onartzen",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} -en biltegiratzea beteta dago, artxiboak ezin dira eguneratu edo sinkronizatu jada!",
    "Your storage is full, files can not be updated or synced anymore!" : "Zure biltegiratzea beterik dago, ezingo duzu aurrerantzean fitxategirik igo edo sinkronizatu!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} -en biltegiratzea ia beteta dago ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Zure biltegiratzea nahiko beterik dago (%{usedSpacePercent})",
    "_matches '{filter}'_::_match '{filter}'_" : ["matches '{filter}'","match '{filter}'"],
    "View in folder" : "karpetan ikusi",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiatu esteka zuzena (bakarrik balio du fitxategi/karpeta honentzat sarbidea duten erabiltzaileentzat)",
    "Path" : "Path",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Gogokoa",
    "Favorite" : "Gogokoa",
    "New folder" : "Karpeta berria",
    "Upload file" : "Igo fitxategia",
    "An error occurred while trying to update the tags" : "Errore bat gertatu da etiketak eguneratzerakoan",
    "Added to favorites" : "Gogokoetan gehitu da",
    "Removed from favorites" : "Gogokoetatik kendu da",
    "You added {file} to your favorites" : "{file} gehitu duzu gogokoetara",
    "You removed {file} from your favorites" : "{file} kendu duzu gogokoetatik",
    "File changes" : "Fitxategi aldaketak",
    "Created by {user}" : "{user} erabiltzaileak sortua",
    "Changed by {user}" : "{user} -k aldatuta",
    "Deleted by {user}" : "{user} -k ezabatuta",
    "Restored by {user}" : "{user} -k zaharberrituta",
    "Renamed by {user}" : "{user} -k berrizendatuta",
    "Moved by {user}" : "{user} -k mugituta",
    "\"remote user\"" : "\"urrutiko erabiltzailea\"",
    "You created {file}" : "Sortu duzu {file}",
    "{user} created {file}" : "{user} {file} sortu du",
    "{file} was created in a public folder" : "{file} fitxategi publiko batean sortu da",
    "You changed {file}" : "Zuk {file} aldatu duzu",
    "{user} changed {file}" : "{user} {file} aldatu du",
    "You deleted {file}" : "{file} ezabatu duzu",
    "{user} deleted {file}" : "{user} {file} ezabatu du",
    "You restored {file}" : "Zuk {file} zaharberritu duzu",
    "{user} restored {file}" : "{user} {file} zaharberritu du",
    "You renamed {oldfile} to {newfile}" : "You renamed {oldfile} to {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} renamed {oldfile} to {newfile}",
    "You moved {oldfile} to {newfile}" : "{oldfile} mugitu duzu hona {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} moved {oldfile} to {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Fitxategi bat gehitu edo kendu da zure <strong>gogokoetatik</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>",
    "A new file or folder has been <strong>created</strong>" : "Fitxategi edo karpeta berri bat <strong>sortu da</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>",
    "Unlimited" : "Mugarik gabe",
    "Upload (max. %s)" : "Igo (max. %s)",
    "File handling" : "Fitxategien kudeaketa",
    "Maximum upload size" : "Igo daitekeen gehienezko tamaina",
    "max. possible: " : "max, posiblea:",
    "Save" : "Gorde",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM-rekin 5 minutu pasa daiteke aldaketak aplikatu ahal izateko.",
    "Missing permissions to edit from here." : "Missing permissions to edit from here.",
    "Settings" : "Ezarpenak",
    "Show hidden files" : "Erakutsi ezkutuko fitxategiak",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Erabili helbide hau <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">WebDAV bidez zure fitxategietara sartzeko </a> ",
    "No files in here" : "Ez dago fitxategirik hemen",
    "Upload some content or sync with your devices!" : "Igo edukiren bat edo sinkronizatu zure gailuekin!",
    "No entries found in this folder" : "Ez da sarrerarik aurkitu karpeta honetan",
    "Select all" : "Hautatu dena",
    "Upload too large" : "Igoera handiegia da",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Igotzen saiatzen ari zaren fitxategiak zerbitzari honek igotzeko onartzen duena baino handiagoak dira.",
    "No favorites yet" : "Gogokorik ez oraindik",
    "Files and folders you mark as favorite will show up here" : "Gogokotzat markatutako fitxategi eta karpeta hemen agertuko dira",
    "Shared with you" : "Zurekin partekatuta",
    "Shared with others" : "Besteekin partekatuta",
    "Shared by link" : "Partekatua link bidez",
    "Tags" : "Etiketak",
    "Deleted files" : "Ezabatutako fitxategiak",
    "Text file" : "Testu fitxategia",
    "New text file.txt" : ".txt testu fitxategi berria",
    "_{hours}:{minutes}:{seconds} hour left_::_{hours}:{minutes}:{seconds} hours left_" : ["Ordu {hours}:{minutes}:{seconds} geratzen da","{hours}:{minutes}:{seconds} ordu geratzen dira"],
    "{hours}:{minutes}h" : "{hours}:{minutes}h",
    "_{minutes}:{seconds} minute left_::_{minutes}:{seconds} minutes left_" : ["Minutu {minutes}:{seconds} geratzen da","{minutes}:{seconds} minutu geratzen dira"],
    "{minutes}:{seconds}m" : "{minutes}:{seconds}m",
    "_{seconds} second left_::_{seconds} seconds left_" : ["Segundu {seconds} geratzen da","{seconds} segundu geratzen dira"],
    "{seconds}s" : "{seconds}s",
    "Any moment now..." : "Edozein unean...",
    "Soon..." : "Laster...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Fitxategien igoera martxan da. Orria orain uzteak igoera ezeztatutko du.",
    "Copy local link" : "Kopiatu tokiko esteka",
    "Folder" : "Karpeta",
    "Upload" : "Igo",
    "A new file or folder has been <strong>deleted</strong>" : "A new file or folder has been <strong>deleted</strong>",
    "A new file or folder has been <strong>restored</strong>" : "A new file or folder has been <strong>restored</strong>",
    "No favorites" : "Gogokorik ez"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/eu.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Biltegiratzea ez dago erabilgarri une honetan",
    "Storage invalid" : "Biltegi bliogabea",
    "Unknown error" : "Errore ezezaguna",
    "All files" : "Fitxategi guztiak",
    "Recent" : "Duela gutxi",
    "Favorites" : "Gogokoak",
    "File could not be found" : "Fitxategia ezin izan da aurkitu",
    "Move or copy" : "Mugitu edo kopiatu",
    "Download" : "Deskargatu",
    "Delete" : "Ezabatu",
    "Home" : "Etxekoa",
    "Close" : "Itxi",
    "Could not create folder \"{dir}\"" : "Ezin izan da \"{dir}\" karpeta sortu",
    "Upload cancelled." : "Igoera ezeztatuta",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ezin da {filename} igo karpeta bat delako edo 0 byte dituelako",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ez dago leku nahikorik, zu {size1} igotzen ari zara baina bakarrik {size2} libre dago",
    "Target folder \"{dir}\" does not exist any more" : "\"{dir}\" karpeta ez du gehiago existitzen",
    "Not enough free space" : "Ez dago nahiko leku librea",
    "Uploading …" : "Igotzen...",
    "…" : "…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} of {totalSize} ({bitrate})",
    "Actions" : "Ekintzak",
    "Rename" : "Berrizendatu",
    "Target folder" : "Xede karpeta",
    "Disconnect storage" : "Deskonektatu biltegia",
    "Unshare" : "Ez elkarbanatu",
    "Could not load info for file \"{file}\"" : "Ezin izan da \"{file}\" fitxategiaren informazioa kargatu",
    "Files" : "Fitxategiak",
    "Details" : "Xehetasunak",
    "Select" : "hautatu",
    "Pending" : "Zain",
    "Unable to determine date" : "Ezin izan da data zehaztu",
    "This operation is forbidden" : "Eragiketa hau debekatuta dago",
    "This directory is unavailable, please check the logs or contact the administrator" : "Direktorio hau ez dago erabilgarri, begira itzazu erregistroa edo administratzailearekin harremanetan jarri",
    "Could not move \"{file}\", target exists" : "Ezin da \"{file}\" mugitu, helburuan existitzen da jadanik",
    "Could not move \"{file}\"" : "Ezin da mugitu \"{file}\"",
    "Could not copy \"{file}\", target exists" : "Ezin da \"{file}\" kopiatu; helburuan existitzen da",
    "Could not copy \"{file}\"" : "Ezin da \"{file}\" kopiatu",
    "Copied {origin} inside {destination}" : "{origin} {destination} barruan kopiatu da",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} eta {nbfiles} beste fitxategiak {destination}-en kopiatu dira",
    "{newName} already exists" : "{newName} existitzen da dagoeneko",
    "Could not rename \"{fileName}\", it does not exist any more" : "Ezin izan da \"{fileName}\" berrizendatu, ez da existitzen",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" izena dagoeneko dago erabilita \"{dir}\" karpetan. Mesedez, beste bat aukeratu.",
    "Could not rename \"{fileName}\"" : "Ezin izan da \"{fileName}\" berrizendatu ",
    "Could not create file \"{file}\"" : "Ezin izan da \"{file}\" fitxategia sortu",
    "Could not create file \"{file}\" because it already exists" : "Ezin izan da \"{file}\" fitxategia sortu, dagoeneko existitzen delako",
    "Could not create folder \"{dir}\" because it already exists" : "Ezin izan da \"{dir}\" karpeta sortu, dagoeneko existitzen delako",
    "Error deleting file \"{fileName}\"." : "Akatsa \"{fileName}\" fitxategia ezabatzerakoan.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Ez da '{tag}{filter}{endtag}' bilaketarako emaitzik aurkitu beste karpetetan",
    "Name" : "Izena",
    "Size" : "Tamaina",
    "Modified" : "Aldatuta",
    "_%n folder_::_%n folders_" : ["karpeta %n","%n karpeta"],
    "_%n file_::_%n files_" : ["fitxategi %n","%n fitxategi"],
    "{dirs} and {files}" : "{dirs} eta {files}",
    "_including %n hidden_::_including %n hidden_" : ["including %n hidden","including %n hidden"],
    "You don’t have permission to upload or create files here" : "Ez duzu fitxategiak hona igotzeko edo hemen sortzeko baimenik",
    "_Uploading %n file_::_Uploading %n files_" : ["Fitxategi %n igotzen","%n fitxategi igotzen"],
    "New" : "Berria",
    "\"{name}\" is an invalid file name." : "\"{name}\" ez da fitxategi izen baliogarria.",
    "File name cannot be empty." : "Fitxategi izena ezin da hutsa izan.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" fitxategi mota ez da onartzen",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} -en biltegiratzea beteta dago, artxiboak ezin dira eguneratu edo sinkronizatu jada!",
    "Your storage is full, files can not be updated or synced anymore!" : "Zure biltegiratzea beterik dago, ezingo duzu aurrerantzean fitxategirik igo edo sinkronizatu!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} -en biltegiratzea ia beteta dago ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Zure biltegiratzea nahiko beterik dago (%{usedSpacePercent})",
    "_matches '{filter}'_::_match '{filter}'_" : ["matches '{filter}'","match '{filter}'"],
    "View in folder" : "karpetan ikusi",
    "Copied!" : "Kopiatua!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiatu esteka zuzena (bakarrik balio du fitxategi/karpeta honentzat sarbidea duten erabiltzaileentzat)",
    "Path" : "Path",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Gogokoa",
    "Favorite" : "Gogokoa",
    "New folder" : "Karpeta berria",
    "Upload file" : "Igo fitxategia",
    "Not favorited" : "Ez da gogokoa",
    "Remove from favorites" : "Gogokoetatik kenduta",
    "Add to favorites" : "Gogokoetara gehitu",
    "An error occurred while trying to update the tags" : "Errore bat gertatu da etiketak eguneratzerakoan",
    "Added to favorites" : "Gogokoetan gehitu da",
    "Removed from favorites" : "Gogokoetatik kendu da",
    "You added {file} to your favorites" : "{file} gehitu duzu gogokoetara",
    "You removed {file} from your favorites" : "{file} kendu duzu gogokoetatik",
    "File changes" : "Fitxategi aldaketak",
    "Created by {user}" : "{user} erabiltzaileak sortua",
    "Changed by {user}" : "{user} -k aldatuta",
    "Deleted by {user}" : "{user} -k ezabatuta",
    "Restored by {user}" : "{user} -k zaharberrituta",
    "Renamed by {user}" : "{user} -k berrizendatuta",
    "Moved by {user}" : "{user} -k mugituta",
    "\"remote user\"" : "\"urrutiko erabiltzailea\"",
    "You created {file}" : "Sortu duzu {file}",
    "{user} created {file}" : "{user} {file} sortu du",
    "{file} was created in a public folder" : "{file} fitxategi publiko batean sortu da",
    "You changed {file}" : "Zuk {file} aldatu duzu",
    "{user} changed {file}" : "{user} {file} aldatu du",
    "You deleted {file}" : "{file} ezabatu duzu",
    "{user} deleted {file}" : "{user} {file} ezabatu du",
    "You restored {file}" : "Zuk {file} zaharberritu duzu",
    "{user} restored {file}" : "{user} {file} zaharberritu du",
    "You renamed {oldfile} to {newfile}" : "You renamed {oldfile} to {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} renamed {oldfile} to {newfile}",
    "You moved {oldfile} to {newfile}" : "{oldfile} mugitu duzu hona {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} moved {oldfile} to {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Fitxategi bat gehitu edo kendu da zure <strong>gogokoetatik</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>",
    "A new file or folder has been <strong>created</strong>" : "Fitxategi edo karpeta berri bat <strong>sortu da</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Fitxategi edo karpeta bat <strong>ezabatu da</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>",
    "A file or folder has been <strong>restored</strong>" : "Fitxategia edo karpeta <strong>berrezarri</strong> da",
    "Unlimited" : "Mugarik gabe",
    "Upload (max. %s)" : "Igo (max. %s)",
    "File handling" : "Fitxategien kudeaketa",
    "Maximum upload size" : "Igo daitekeen gehienezko tamaina",
    "max. possible: " : "max, posiblea:",
    "Save" : "Gorde",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM-rekin 5 minutu pasa daiteke aldaketak aplikatu ahal izateko.",
    "Missing permissions to edit from here." : "Missing permissions to edit from here.",
    "%s of %s used" : "%s - %s-tik erabilita",
    "%s used" : "%s erabilita",
    "Settings" : "Ezarpenak",
    "Show hidden files" : "Erakutsi ezkutuko fitxategiak",
    "WebDAV" : "WebDAV",
    "Cancel upload" : "Igoera bertan behera utzita",
    "No files in here" : "Ez dago fitxategirik hemen",
    "Upload some content or sync with your devices!" : "Igo edukiren bat edo sinkronizatu zure gailuekin!",
    "No entries found in this folder" : "Ez da sarrerarik aurkitu karpeta honetan",
    "Select all" : "Hautatu dena",
    "Upload too large" : "Igoera handiegia da",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Igotzen saiatzen ari zaren fitxategiak zerbitzari honek igotzeko onartzen duena baino handiagoak dira.",
    "No favorites yet" : "Gogokorik ez oraindik",
    "Files and folders you mark as favorite will show up here" : "Gogokotzat markatutako fitxategi eta karpeta hemen agertuko dira",
    "Tags" : "Etiketak",
    "Deleted files" : "Ezabatutako fitxategiak",
    "Text file" : "Testu fitxategia",
    "New text file.txt" : ".txt testu fitxategi berria",
    "Shared with you" : "Zurekin partekatuta",
    "Shared with others" : "Besteekin partekatuta",
    "Shared by link" : "Partekatua link bidez"
},
"nplurals=2; plural=(n != 1);");
